@@ -5,5 +5,7 @@
                            "latitude", "longitude", "site.type",
                            ".", "data", "fit", "grp", "intercept", "out",
                            "seslope", "slope", "weekday", "cuts", "empty",
-                           "lat", "lon", "traj_len", "wkday"))
+                           "lat", "lon", "traj_len", "wkday", "date_end",
+                           "validity", "process", "parameter", "date_start",
+                           "site"))
 }
